@@ -27,9 +27,11 @@ class CreatePrefetchTaskRequest(AbstractModel):
         r"""
         :param ZoneId: Zone ID
         :type ZoneId: str
-        :param Targets: 预热的资源列表
+        :param Targets: 要预热的资源列表，每个元素格式类似如下:
+http://www.example.com/example.txt
         :type Targets: list of str
         :param EncodeUrl: 是否对url进行encode
+若内容含有非 ASCII 字符集的字符，请开启此开关，编码转换（编码规则遵循 RFC3986）
         :type EncodeUrl: bool
         :param Headers: 附带的http头部信息
         :type Headers: list of Header
@@ -105,10 +107,18 @@ class CreatePurgeTaskRequest(AbstractModel):
 - purge_host：Hostname
 - purge_all：全部缓存
         :type Type: str
-        :param Targets: 内容，一行一个
+        :param Targets: 要刷新的资源列表，每个元素格式依据Type而定
+1) Type = purge_host 时
+形如：www.example.com 或 foo.bar.example.com
+2) Type = purge_prefix 时
+形如：http://www.example.com/example
+3) Type = purge_url 时
+形如：https://www.example.com/example.jpg
+4）Type = purge_all 时
+Targets可为空，不需要填写
         :type Targets: list of str
         :param EncodeUrl: 若有编码转换，仅清除编码转换后匹配的资源
-若内容含有非 ASCII 字符集的字符，请打开 URL Encode 开关，编码转换（编码规则遵循 RFC3986）
+若内容含有非 ASCII 字符集的字符，请开启此开关，编码转换（编码规则遵循 RFC3986）
         :type EncodeUrl: bool
         """
         self.ZoneId = None
@@ -347,11 +357,11 @@ class DescribeZonesRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Offset: 分页参数，页偏移
+        :param Offset: 分页查询偏移量。默认值：0，最小值：0。
         :type Offset: int
-        :param Limit: 分页参数，每页返回的站点个数
+        :param Limit: 分页查询限制数目。默认值：1000，最大值：1000。
         :type Limit: int
-        :param Filters: 查询条件过滤器，复杂类型
+        :param Filters: 查询条件过滤器，复杂类型。
         :type Filters: list of ZoneFilter
         """
         self.Offset = None
@@ -384,10 +394,9 @@ class DescribeZonesResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param TotalCount: 符合条件的站点数
+        :param TotalCount: 符合条件的站点个数。
         :type TotalCount: int
-        :param Zones: 站点详细信息列表
-注意：此字段可能返回 null，表示取不到有效值。
+        :param Zones: 站点详细信息列表。
         :type Zones: list of Zone
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -417,7 +426,8 @@ class FailReason(AbstractModel):
         r"""
         :param Reason: 失败原因
         :type Reason: str
-        :param Targets: 失败列表
+        :param Targets: 处理失败的资源列表。
+该列表元素来源于输入参数中的Targets，因此格式和入参中的Targets保持一致
         :type Targets: list of str
         """
         self.Reason = None
@@ -464,6 +474,138 @@ class Header(AbstractModel):
         
 
 
+class Resource(AbstractModel):
+    """计费资源
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Id: 资源 ID。
+        :type Id: str
+        :param PayMode: 付费模式，取值有：
+<li>0：后付费。</li>
+        :type PayMode: int
+        :param CreateTime: 创建时间。
+        :type CreateTime: str
+        :param EnableTime: 生效时间。
+        :type EnableTime: str
+        :param ExpireTime: 失效时间。
+        :type ExpireTime: str
+        :param Status: 套餐状态，取值有：
+<li>normal：正常；</li>
+<li>isolated：隔离；</li>
+<li>destroyed：销毁。</li>
+        :type Status: str
+        :param Sv: 询价参数。
+        :type Sv: list of Sv
+        :param AutoRenewFlag: 是否自动续费，取值有：
+<li>0：默认状态；</li>
+<li>1：自动续费；</li>
+<li>2：不自动续费。</li>
+        :type AutoRenewFlag: int
+        :param PlanId: 套餐关联资源 ID。
+        :type PlanId: str
+        :param Area: 地域，取值有：
+<li>mainland：国内；</li>
+<li>overseas：海外。</li>
+        :type Area: str
+        """
+        self.Id = None
+        self.PayMode = None
+        self.CreateTime = None
+        self.EnableTime = None
+        self.ExpireTime = None
+        self.Status = None
+        self.Sv = None
+        self.AutoRenewFlag = None
+        self.PlanId = None
+        self.Area = None
+
+
+    def _deserialize(self, params):
+        self.Id = params.get("Id")
+        self.PayMode = params.get("PayMode")
+        self.CreateTime = params.get("CreateTime")
+        self.EnableTime = params.get("EnableTime")
+        self.ExpireTime = params.get("ExpireTime")
+        self.Status = params.get("Status")
+        if params.get("Sv") is not None:
+            self.Sv = []
+            for item in params.get("Sv"):
+                obj = Sv()
+                obj._deserialize(item)
+                self.Sv.append(obj)
+        self.AutoRenewFlag = params.get("AutoRenewFlag")
+        self.PlanId = params.get("PlanId")
+        self.Area = params.get("Area")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class Sv(AbstractModel):
+    """询价参数
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Key: 询价参数键。
+        :type Key: str
+        :param Value: 询价参数值。
+        :type Value: str
+        """
+        self.Key = None
+        self.Value = None
+
+
+    def _deserialize(self, params):
+        self.Key = params.get("Key")
+        self.Value = params.get("Value")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class Tag(AbstractModel):
+    """标签配置
+
+    """
+
+    def __init__(self):
+        r"""
+        :param TagKey: 标签键
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TagKey: str
+        :param TagValue: 标签值
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TagValue: str
+        """
+        self.TagKey = None
+        self.TagValue = None
+
+
+    def _deserialize(self, params):
+        self.TagKey = params.get("TagKey")
+        self.TagValue = params.get("TagValue")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class Task(AbstractModel):
     """内容管理任务结果
 
@@ -515,30 +657,47 @@ class Zone(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Id: 站点ID
+        :param Id: 站点ID。
         :type Id: str
-        :param Name: 站点名称
+        :param Name: 站点名称。
         :type Name: str
-        :param OriginalNameServers: 站点当前使用的 NS 列表
+        :param OriginalNameServers: 站点当前使用的 NS 列表。
         :type OriginalNameServers: list of str
-        :param NameServers: 腾讯云分配的 NS 列表
+        :param NameServers: 腾讯云分配的 NS 列表。
         :type NameServers: list of str
-        :param Status: 站点状态
-- active：NS 已切换
-- pending：NS 未切换
-- moved：NS 已切走
-- deactivated：被封禁
+        :param Status: 站点状态，取值有：
+<li> active：NS 已切换； </li>
+<li> pending：NS 未切换；</li>
+<li> moved：NS 已切走；</li>
+<li> deactivated：被封禁。 </li>
         :type Status: str
-        :param Type: 站点接入方式
-- full：NS 接入
-- partial：CNAME 接入
+        :param Type: 站点接入方式，取值有
+<li> full：NS 接入； </li>
+<li> partial：CNAME 接入。</li>
         :type Type: str
-        :param Paused: 站点是否关闭
+        :param Paused: 站点是否关闭。
         :type Paused: bool
-        :param CreatedOn: 站点创建时间
+        :param CnameSpeedUp: 是否开启cname加速，取值有：
+<li> enabled：开启；</li>
+<li> disabled：关闭。</li>
+        :type CnameSpeedUp: str
+        :param CnameStatus: cname 接入状态，取值有：
+<li> finished：站点已验证；</li>
+<li> pending：站点验证中。</li>
+        :type CnameStatus: str
+        :param Tags: 资源标签列表。
+        :type Tags: list of Tag
+        :param Resources: 计费资源列表。
+        :type Resources: list of Resource
+        :param CreatedOn: 站点创建时间。
         :type CreatedOn: str
-        :param ModifiedOn: 站点修改时间
+        :param ModifiedOn: 站点修改时间。
         :type ModifiedOn: str
+        :param Area: 站点接入地域，取值为：
+<li> global：全球；</li>
+<li> mainland：中国大陆；</li>
+<li> overseas：境外区域。</li>
+        :type Area: str
         """
         self.Id = None
         self.Name = None
@@ -547,8 +706,13 @@ class Zone(AbstractModel):
         self.Status = None
         self.Type = None
         self.Paused = None
+        self.CnameSpeedUp = None
+        self.CnameStatus = None
+        self.Tags = None
+        self.Resources = None
         self.CreatedOn = None
         self.ModifiedOn = None
+        self.Area = None
 
 
     def _deserialize(self, params):
@@ -559,8 +723,23 @@ class Zone(AbstractModel):
         self.Status = params.get("Status")
         self.Type = params.get("Type")
         self.Paused = params.get("Paused")
+        self.CnameSpeedUp = params.get("CnameSpeedUp")
+        self.CnameStatus = params.get("CnameStatus")
+        if params.get("Tags") is not None:
+            self.Tags = []
+            for item in params.get("Tags"):
+                obj = Tag()
+                obj._deserialize(item)
+                self.Tags.append(obj)
+        if params.get("Resources") is not None:
+            self.Resources = []
+            for item in params.get("Resources"):
+                obj = Resource()
+                obj._deserialize(item)
+                self.Resources.append(obj)
         self.CreatedOn = params.get("CreatedOn")
         self.ModifiedOn = params.get("ModifiedOn")
+        self.Area = params.get("Area")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -578,12 +757,14 @@ class ZoneFilter(AbstractModel):
     def __init__(self):
         r"""
         :param Name: 过滤字段名，支持的列表如下：
-- name: 站点名。
-- status: 站点状态
+<li> name：站点名；</li>
+<li> status：站点状态；</li>
+<li> tagKey：标签键；</li>
+<li> tagValue: 标签值。</li>
         :type Name: str
-        :param Values: 过滤字段值
+        :param Values: 过滤字段值。
         :type Values: list of str
-        :param Fuzzy: 是否启用模糊查询，仅支持过滤字段名为name。模糊查询时，Values长度最大为1
+        :param Fuzzy: 是否启用模糊查询，仅支持过滤字段名为name。模糊查询时，Values长度最大为1。默认为false。
         :type Fuzzy: bool
         """
         self.Name = None
